Revert "Zero blocks before BLKDISCARD"

This reverts commit 96392b97f6bf1670d478494fb6df89a3410e53fa.

Change-Id: I77acc27158bad3cd8948390a3955197646a43a31
diff --git a/updater/blockimg.c b/updater/blockimg.c
index dfba7e4..5d0f156 100644
--- a/updater/blockimg.c
+++ b/updater/blockimg.c
@@ -39,6 +39,11 @@
 
 #define BLOCKSIZE 4096
 
+// Set this to 0 to interpret 'erase' transfers to mean do a
+// BLKDISCARD ioctl (the normal behavior).  Set to 1 to interpret
+// erase to mean fill the region with zeroes.
+#define DEBUG_ERASE  0
+
 #ifndef BLKDISCARD
 #define BLKDISCARD _IO(0x12,119)
 #endif
@@ -1278,7 +1283,8 @@
     }
 
     if (params->cmdname[0] == 'z') {
         // Update only for the zero command, as the erase command will call this
         params->written += tgt->size;
     }
 
@@ -1464,10 +1470,8 @@
     struct stat st;
     uint64_t blocks[2];
 
-    // Always zero the blocks first to work around possibly flaky BLKDISCARD
-    // Bug: 20881595
-    if (PerformCommandZero(params) != 0) {
-        goto pceout;
+    if (DEBUG_ERASE) {
+        return PerformCommandZero(params);
     }
 
     if (!params) {
@@ -1278,7 +1283,8 @@
 
     if (params->cmdname[0] == 'z') {
-        // Update only for the zero command, as the erase command will call this
+        // Update only for the zero command, as the erase command will call
+        // this if DEBUG_ERASE is defined.
         params->written += tgt->size;
     }